@@ -1,21 +1,7 @@
 require 'spec_helper_acceptance'
+require_relative './version.rb'
 
-describe 'apache::mod::php class', :unless => UNSUPPORTED_PLATFORMS.include?(fact('osfamily')) do
-  case fact('osfamily')
-  when 'Debian'
-    vhost_dir    = '/etc/apache2/sites-enabled'
-    mod_dir      = '/etc/apache2/mods-available'
-    service_name = 'apache2'
-  when 'RedHat'
-    vhost_dir    = '/etc/httpd/conf.d'
-    mod_dir      = '/etc/httpd/conf.d'
-    service_name = 'httpd'
-  when 'FreeBSD'
-    vhost_dir    = '/usr/local/etc/apache22/Vhosts'
-    mod_dir      = '/usr/local/etc/apache22/Modules'
-    service_name = 'apache22'
-  end
-
+describe 'apache::mod::php class' do
   context "default php config" do
     it 'succeeds in puppeting php' do
       pp= <<-EOS
@@ -36,24 +22,28 @@ describe 'apache::mod::php class', :unless => UNSUPPORTED_PLATFORMS.include?(fac
       apply_manifest(pp, :catch_failures => true)
     end
 
-    describe service(service_name) do
-      it { should be_enabled }
-      it { should be_running }
+    describe service($service_name) do
+      if (fact('operatingsystem') == 'Debian' && fact('operatingsystemmajrelease') == '8')
+        pending 'Should be enabled - Bug 760616 on Debian 8'
+      else
+        it { should be_enabled }
+      end
+      it { is_expected.to be_running }
     end
 
-    describe file("#{mod_dir}/php5.conf") do
-      it { should contain "DirectoryIndex index.php" }
+    describe file("#{$mod_dir}/php5.conf") do
+      it { is_expected.to contain "DirectoryIndex index.php" }
     end
 
     it 'should answer to php.example.com' do
       shell("/usr/bin/curl php.example.com:80") do |r|
-        r.stdout.should =~ /PHP Version/
-        r.exit_code.should == 0
+        expect(r.stdout).to match(/PHP Version/)
+        expect(r.exit_code).to eq(0)
       end
     end
   end
 
-  context "custom extensions, php_admin_flag, and php_admin_value" do
+  context "custom extensions, php_flag, php_value, php_admin_flag, and php_admin_value" do
     it 'succeeds in puppeting php' do
       pp= <<-EOS
         class { 'apache':
@@ -65,6 +55,8 @@ describe 'apache::mod::php class', :unless => UNSUPPORTED_PLATFORMS.include?(fac
         apache::vhost { 'php.example.com':
           port             => '80',
           docroot          => '/var/www/php',
+          php_values       => { 'include_path' => '.:/usr/share/pear:/usr/bin/php', },
+          php_flags        => { 'display_errors' => 'on', },
           php_admin_values => { 'open_basedir' => '/var/www/php/:/usr/share/pear/', },
           php_admin_flags  => { 'engine' => 'on', },
         }
@@ -77,21 +69,65 @@ describe 'apache::mod::php class', :unless => UNSUPPORTED_PLATFORMS.include?(fac
       apply_manifest(pp, :catch_failures => true)
     end
 
-    describe service(service_name) do
-      it { should be_enabled }
-      it { should be_running }
+    describe service($service_name) do
+      if (fact('operatingsystem') == 'Debian' && fact('operatingsystemmajrelease') == '8')
+        pending 'Should be enabled - Bug 760616 on Debian 8'
+      else
+        it { should be_enabled }
+      end
+      it { is_expected.to be_running }
     end
 
-    describe file("#{vhost_dir}/25-php.example.com.conf") do
-      it { should contain "  php_admin_flag engine on" }
-      it { should contain "  php_admin_value open_basedir /var/www/php/:/usr/share/pear/" }
+    describe file("#{$vhost_dir}/25-php.example.com.conf") do
+      it { is_expected.to contain "  php_flag display_errors on" }
+      it { is_expected.to contain "  php_value include_path \".:/usr/share/pear:/usr/bin/php\"" }
+      it { is_expected.to contain "  php_admin_flag engine on" }
+      it { is_expected.to contain "  php_admin_value open_basedir /var/www/php/:/usr/share/pear/" }
     end
 
     it 'should answer to php.example.com' do
       shell("/usr/bin/curl php.example.com:80") do |r|
-        r.stdout.should =~ /\/usr\/share\/pear\//
-        r.exit_code.should == 0
+        expect(r.stdout).to match(/\/usr\/share\/pear\//)
+        expect(r.exit_code).to eq(0)
       end
     end
   end
+
+  context "provide custom config file" do
+    it 'succeeds in puppeting php' do
+      pp= <<-EOS
+        class {'apache':
+          mpm_module => 'prefork',
+        }
+        class {'apache::mod::php':
+          content => '# somecontent',
+        }
+      EOS
+      apply_manifest(pp, :catch_failures => true)
+    end
+
+    describe file("#{$mod_dir}/php5.conf") do
+      it { should contain "# somecontent" }
+    end
+  end
+
+  context "provide content and template config file" do
+    it 'succeeds in puppeting php' do
+      pp= <<-EOS
+        class {'apache':
+          mpm_module => 'prefork',
+        }
+        class {'apache::mod::php':
+          content  => '# somecontent',
+          template => 'apache/mod/php5.conf.erb',
+        }
+      EOS
+      apply_manifest(pp, :catch_failures => true)
+    end
+
+    describe file("#{$mod_dir}/php5.conf") do
+      it { should contain "# somecontent" }
+    end
+  end
+
 end
