@@ -1,15 +1,5 @@
 require 'spec_helper_acceptance'
-
-case fact('osfamily')
-when 'RedHat'
-  servicename = 'httpd'
-when 'Debian'
-  servicename = 'apache2'
-when 'FreeBSD'
-  servicename = 'apache24'
-when 'Gentoo'
-  servicename = 'apache2'
-end
+require_relative './version.rb'
 
 case fact('osfamily')
 when 'FreeBSD'
@@ -29,53 +19,62 @@ when 'FreeBSD'
       end
     end
 
-    describe service(servicename) do
+    describe service($service_name) do
       it { is_expected.to be_running }
-      it { is_expected.to be_enabled }
+      if (fact('operatingsystem') == 'Debian' && fact('operatingsystemmajrelease') == '8')
+        pending 'Should be enabled - Bug 760616 on Debian 8'
+      else
+        it { should be_enabled }
+      end
     end
   end
 end
 
-describe 'apache::mod::worker class', :unless => UNSUPPORTED_PLATFORMS.include?(fact('osfamily')) do
+describe 'apache::mod::worker class' do
   describe 'running puppet code' do
     # Using puppet_apply as a helper
-    it 'should work with no errors' do
-      pp = <<-EOS
+    let(:pp) do
+      <<-EOS
         class { 'apache':
           mpm_module => 'worker',
         }
       EOS
-
-      # Run it twice and test for idempotency
-      apply_manifest(pp, :catch_failures => true)
-      expect(apply_manifest(pp, :catch_failures => true).exit_code).to be_zero
     end
+
+    # Run it twice and test for idempotency
+    it_behaves_like "a idempotent resource"
   end
 
-  describe service(servicename) do
+  describe service($service_name) do
     it { is_expected.to be_running }
-    it { is_expected.to be_enabled }
+    if (fact('operatingsystem') == 'Debian' && fact('operatingsystemmajrelease') == '8')
+      pending 'Should be enabled - Bug 760616 on Debian 8'
+    else
+      it { should be_enabled }
+    end
   end
 end
 
-describe 'apache::mod::prefork class', :unless => UNSUPPORTED_PLATFORMS.include?(fact('osfamily')) do
+describe 'apache::mod::prefork class' do
   describe 'running puppet code' do
     # Using puppet_apply as a helper
-    it 'should work with no errors' do
-      pp = <<-EOS
+    let(:pp) do
+      <<-EOS
         class { 'apache':
           mpm_module => 'prefork',
         }
       EOS
+    end
+    # Run it twice and test for idempotency
+    it_behaves_like "a idempotent resource"
+  end
 
-      # Run it twice and test for idempotency
-      apply_manifest(pp, :catch_failures => true)
-      expect(apply_manifest(pp, :catch_failures => true).exit_code).to be_zero
+  describe service($service_name) do
+    it { is_expected.to be_running }
+    if (fact('operatingsystem') == 'Debian' && fact('operatingsystemmajrelease') == '8')
+      pending 'Should be enabled - Bug 760616 on Debian 8'
+    else
+      it { should be_enabled }
     end
   end
-
-  describe service(servicename) do
-    it { is_expected.to be_running }
-    it { is_expected.to be_enabled }
-  end
 end
