@@ -1,12 +1,12 @@
+require 'spec_helper'
+
 # This function is called inside the OS specific contexts
 def general_mime_magic_specs
-  it { should contain_apache__mod("mime_magic") }
+  it { is_expected.to contain_apache__mod("mime_magic") }
 end
 
 describe 'apache::mod::mime_magic', :type => :class do
-  let :pre_condition do
-    'include apache'
-  end
+  it_behaves_like "a mod class, without including apache"
 
   context "On a Debian OS with default params" do
     let :facts do
@@ -14,22 +14,28 @@ describe 'apache::mod::mime_magic', :type => :class do
         :osfamily               => 'Debian',
         :operatingsystemrelease => '6',
         :concat_basedir         => '/dne',
+        :lsbdistcodename        => 'squeeze',
+        :operatingsystem        => 'Debian',
+        :id                     => 'root',
+        :kernel                 => 'Linux',
+        :path                   => '/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin',
+        :is_pe                  => false,
       }
     end
 
     general_mime_magic_specs()
 
     it do
-      should contain_file("mime_magic.conf").with_content(
+      is_expected.to contain_file("mime_magic.conf").with_content(
         "MIMEMagicFile \"/etc/apache2/magic\"\n"
       )
     end
 
-    it { should contain_file("mime_magic.conf").with({
+    it { is_expected.to contain_file("mime_magic.conf").with({
       :ensure => 'file',
       :path   => '/etc/apache2/mods-available/mime_magic.conf',
     } ) }
-    it { should contain_file("mime_magic.conf symlink").with({
+    it { is_expected.to contain_file("mime_magic.conf symlink").with({
       :ensure => 'link',
       :path   => '/etc/apache2/mods-enabled/mime_magic.conf',
     } ) }
@@ -40,7 +46,7 @@ describe 'apache::mod::mime_magic', :type => :class do
       end
 
       it do
-        should contain_file("mime_magic.conf").with_content(
+        is_expected.to contain_file("mime_magic.conf").with_content(
           "MIMEMagicFile \"/tmp/Debian_magic\"\n"
         )
       end
@@ -54,18 +60,23 @@ describe 'apache::mod::mime_magic', :type => :class do
         :osfamily               => 'RedHat',
         :operatingsystemrelease => '6',
         :concat_basedir         => '/dne',
+        :operatingsystem        => 'RedHat',
+        :id                     => 'root',
+        :kernel                 => 'Linux',
+        :path                   => '/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin',
+        :is_pe                  => false,
       }
     end
 
     general_mime_magic_specs()
 
     it do
-      should contain_file("mime_magic.conf").with_content(
+      is_expected.to contain_file("mime_magic.conf").with_content(
         "MIMEMagicFile \"/etc/httpd/conf/magic\"\n"
       )
     end
 
-    it { should contain_file("mime_magic.conf").with_path("/etc/httpd/conf.d/mime_magic.conf") }
+    it { is_expected.to contain_file("mime_magic.conf").with_path("/etc/httpd/conf.d/mime_magic.conf") }
 
   end
 
@@ -75,6 +86,12 @@ describe 'apache::mod::mime_magic', :type => :class do
         :osfamily               => 'Debian',
         :operatingsystemrelease => '6',
         :concat_basedir         => '/dne',
+        :lsbdistcodename        => 'squeeze',
+        :operatingsystem        => 'Debian',
+        :id                     => 'root',
+        :kernel                 => 'Linux',
+        :path                   => '/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin',
+        :is_pe                  => false,
       }
     end
 
@@ -83,7 +100,7 @@ describe 'apache::mod::mime_magic', :type => :class do
     end
 
     it do
-      should contain_file("mime_magic.conf").with_content(
+      is_expected.to contain_file("mime_magic.conf").with_content(
         "MIMEMagicFile \"/tmp/magic\"\n"
       )
     end
