@@ -3,11 +3,11 @@ require 'spec_helper'
 describe 'apache::mod::proxy_html', :type => :class do
   let :pre_condition do
     [
-      'include apache',
       'include apache::mod::proxy',
       'include apache::mod::proxy_http',
     ]
   end
+  it_behaves_like "a mod class, without including apache"
   context "on a Debian OS" do
     shared_examples "debian" do |loadfiles|
       it { is_expected.to contain_class("apache::params") }
@@ -25,16 +25,36 @@ describe 'apache::mod::proxy_html', :type => :class do
         :kernel          => 'Linux',
         :path            => '/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin',
         :hardwaremodel   => 'i386',
-        :is_pe                  => false,
+        :is_pe           => false,
       }
     end
 
     context "on squeeze" do
       let(:facts) { super().merge({ :operatingsystemrelease => '6' }) }
       it_behaves_like "debian", ['/usr/lib/libxml2.so.2']
+      it { is_expected.to_not contain_apache__mod('xml2enc') }
     end
     context "on wheezy" do
       let(:facts) { super().merge({ :operatingsystemrelease => '7' }) }
+      it { is_expected.to_not contain_apache__mod('xml2enc') }
+      context "i386" do
+        let(:facts) { super().merge({
+          :hardwaremodel => 'i686',
+          :architecture  => 'i386'
+        })}
+        it_behaves_like "debian", ["/usr/lib/i386-linux-gnu/libxml2.so.2"]
+      end
+      context "x64" do
+        let(:facts) { super().merge({
+          :hardwaremodel => 'x86_64',
+          :architecture  => 'amd64'
+        })}
+        it_behaves_like "debian", ["/usr/lib/x86_64-linux-gnu/libxml2.so.2"]
+      end
+    end
+    context "on jessie" do
+      let(:facts) { super().merge({ :operatingsystemrelease => '8' }) }
+      it { is_expected.to contain_apache__mod('xml2enc').with(:loadfiles => nil) }
       context "i386" do
         let(:facts) { super().merge({
           :hardwaremodel => 'i686',
@@ -67,6 +87,7 @@ describe 'apache::mod::proxy_html', :type => :class do
     it { is_expected.to contain_class("apache::params") }
     it { is_expected.to contain_apache__mod('proxy_html').with(:loadfiles => nil) }
     it { is_expected.to contain_package("mod_proxy_html") }
+    it { is_expected.to contain_apache__mod('xml2enc').with(:loadfiles => nil) }
   end
   context "on a FreeBSD OS", :compile do
     let :facts do
@@ -83,6 +104,7 @@ describe 'apache::mod::proxy_html', :type => :class do
     end
     it { is_expected.to contain_class("apache::params") }
     it { is_expected.to contain_apache__mod('proxy_html').with(:loadfiles => nil) }
+    it { is_expected.to contain_apache__mod('xml2enc').with(:loadfiles => nil) }
     it { is_expected.to contain_package("www/mod_proxy_html") }
   end
   context "on a Gentoo OS", :compile do
@@ -100,6 +122,7 @@ describe 'apache::mod::proxy_html', :type => :class do
     end
     it { is_expected.to contain_class("apache::params") }
     it { is_expected.to contain_apache__mod('proxy_html').with(:loadfiles => nil) }
+    it { is_expected.to contain_apache__mod('xml2enc').with(:loadfiles => nil) }
     it { is_expected.to contain_package("www-apache/mod_proxy_html") }
   end
 end
