@@ -1,9 +1,7 @@
 require 'spec_helper'
 
 describe 'apache::mod::speling', :type => :class do
-  let :pre_condition do
-    'include apache'
-  end
+  it_behaves_like "a mod class, without including apache"
   context "on a Debian OS" do
     let :facts do
       {
